<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:param name="imgroot"/>
  <xsl:param name="showdetails"/>
  <xsl:param name="location"/>
  <xsl:param name="feelslike"/>
  <xsl:param name="uv"/>
  <xsl:param name="dewpoint"/>
  <xsl:param name="humidity"/>
  <xsl:param name="visibility"/>
  <xsl:param name="miles"/>
  <xsl:param name="pressure"/>
  <xsl:param name="and"/>
  <xsl:param name="wind"/>
  <xsl:param name="iconlarge"/>
  <xsl:param name="iconsmall"/>
  <xsl:param name="daylight"/>
  <xsl:param name="at"/>
  <xsl:param name="timestamp"/>
  <xsl:param name="extended"/>
  
  <xsl:template match="/weather">
  
  <xsl:apply-templates select="withExtended"/>
  
  	<xsl:variable name="med-img-dir">/default/</xsl:variable>
    <xsl:variable name="img-ext">png</xsl:variable>
    <xsl:variable name="iconnumber"><xsl:value-of select="cc/icon"/></xsl:variable>
  

<div id="location">
	<xsl:if test="$location='dnam'">
		<xsl:value-of select="loc/dnam"/>
	</xsl:if>
	<xsl:if test="$location='obst'">
		<xsl:value-of select="cc/obst"/>
	</xsl:if>
</div>
<div id="image">
	<img src="{$imgroot}{$med-img-dir}{$iconlarge}/{$iconnumber}.{$img-ext}"/>
</div>
<div id="forecast">
	<font class="Head"><xsl:value-of select="cc/tmp"/><xsl:value-of select="head/ut"/></font><br/>
	<font class="Normal"><xsl:value-of select="$feelslike" />&#160;<xsl:value-of select="cc/flik"/><xsl:value-of select="head/ut"/></font><br/>
	<font class="SubHead"><xsl:value-of select="cc/t"/></font>
</div>
<xsl:if test="$timestamp='true'">
<div id="timestamp">
	<xsl:value-of select="cc/lsup"/>
</div>
</xsl:if>

    <xsl:if test="$showdetails='true'">
      <br clear="all"/>
      <table border="0" cellSpacing="0" cellPadding="0" class="Normal">
		<tr>
          <td width="10%"></td>
          <td align="right" valign="center"><xsl:value-of select="$uv" />&#160;</td>
          <td align="left" valign="center">
            <xsl:value-of select="cc/uv/i"/> - <xsl:value-of select="cc/uv/t"/>
          </td>
        </tr>
        <tr>
          <td width="10%"></td>
          <td align="right" valign="center" nowrap="nowrap"><xsl:value-of select="$dewpoint" />&#160;</td>
          <td align="left" valign="center">
            <xsl:value-of select="cc/dewp"/><xsl:value-of select="head/ut"/>
          </td>
        </tr>
        <tr>
          <td width="10%"></td>
          <td align="right" valign="center"><xsl:value-of select="$humidity" />&#160;</td>
          <td align="left" valign="center">
            <xsl:value-of select="cc/hmid"/>%
          </td>
        </tr>
        <tr>
          <td width="10%"></td>
          <td align="right" valign="center"><xsl:value-of select="$visibility" />&#160;</td>
          <td align="left" valign="center">
            <xsl:value-of select="cc/vis"/>&#160;<xsl:value-of select="head/ud"/>
          </td>
        </tr>
        <tr>
          <td width="10%"></td>
          <td align="right" valign="top"><xsl:value-of select="$pressure" />&#160;</td>
          <td align="left" valign="top">
            <xsl:value-of select="cc/bar/r"/>&#160;<xsl:value-of select="head/up"/>&#160;<xsl:value-of select="$and" />&#160;<xsl:value-of select="cc/bar/d"/>
          </td>
        </tr>
        <tr>
          <td width="10%"></td>
          <td align="right" valign="top"><xsl:value-of select="$daylight" />&#160;</td>
          <td align="left" valign="top">
			<xsl:value-of select="loc/sunr" />&#160;-&#160;<xsl:value-of select="loc/suns" />
          </td>
        </tr>
		<tr>
          <td width="10%"></td>
          <td align="right" valign="top"><xsl:value-of select="$wind" />&#160;</td>
          <td align="left" valign="top">
			<xsl:choose>
				<xsl:when test="cc/wind/s &gt; 0">
					<xsl:value-of select="cc/wind/t" />&#160;<xsl:value-of select="$at" />&#160;<xsl:value-of select="cc/wind/s"/>&#160;<xsl:value-of select="head/us"/>
					<xsl:if test="cc/wind/d &gt; 0">&#160;<xsl:value-of select="cc/wind/d" /></xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="cc/wind/t" />
				</xsl:otherwise>
			</xsl:choose>
          </td>
        </tr>
      </table>
      </xsl:if>
    
    <br clear="all"/>
      <xsl:variable name="day-span" select="count(//dayf/day)-1"/>
      <xsl:if test="$day-span > 0">
      
    <table cellSpacing="0" cellPadding="3" class="Normal" border="0" rules="cols" frame="void">
        <tr>
          <td colspan="{$day-span}" width="100%" align="center" class="SubHead"><xsl:value-of select="$extended" /></td>
        </tr>
        <tr>
          <xsl:for-each select="dayf/day">
            <xsl:if test="@d > 0">
              <td width="25%" align="center" valign="top">
                <xsl:value-of select="@t"></xsl:value-of>
              </td>
            </xsl:if>
          </xsl:for-each>
        </tr>
        <tr>
          <xsl:variable name="small-img-dir">/default/</xsl:variable>

          <xsl:for-each select="dayf/day">
            <xsl:if test="@d > 0">
              <xsl:variable name="extendediconnumber"><xsl:value-of select="part/icon"/></xsl:variable>
              <td width="25%" align="center" valign="center">
                <img src="{$imgroot}{$small-img-dir}{$iconsmall}/{$extendediconnumber}.{$img-ext}"></img>
              </td>
            </xsl:if>
          </xsl:for-each>
        </tr>
        <tr>
          <xsl:for-each select="dayf/day">
            <xsl:if test="@d > 0">
              <td width="25%" align="center" valign="top" class="Small" nowrap="nowrap">
                <xsl:value-of select="hi"/><xsl:value-of select="//head//ut"/> / <xsl:value-of select="low"/><xsl:value-of select="//head//ut"/>
              </td>
            </xsl:if>
          </xsl:for-each>
        </tr>
        <tr>
          <xsl:for-each select="dayf/day">
            <xsl:if test="@d > 0">
              <td width="25%" align="center" valign="top">
                <xsl:value-of select="part/t"/>
              </td>
            </xsl:if>
          </xsl:for-each>
        </tr>
      </table>
      </xsl:if>

  </xsl:template>
</xsl:stylesheet>